/*
 * Copyright (C) 2007 Copyright (C) 2007 daniel g. siegel <dgsiegel@gmail.com>
 *
 * Licensed under the GNU General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CHEESE_EFFECTS_WIDGET_H__
#define __CHEESE_EFFECTS_WIDGET_H__

void cheese_effects_widget_init (void);
void cheese_effects_widget_finalize (void);
gchar *cheese_effects_get_selection (void);
void cheese_effects_widget_remove_all_effects (void);

#endif /* __CHEESE_EFFECTS_WIDGET_H__ */
